@@ -26,6 +26,7 @@ import tempfile
 import time
 
 from oslo_utils import strutils
+import yaml
 
 from ironicclient.common.i18n import _
 from ironicclient import exc
@@ -213,7 +214,7 @@ def common_params_for_list(args, fields, field_labels):
 
 
 def common_filters(marker=None, limit=None, sort_key=None, sort_dir=None,
-                   fields=None, detail=False):
+                   fields=None, detail=False, project=None, public=None):
     """Generate common filters for any list request.
 
     :param marker: entity ID from which to start returning entities.
@@ -236,6 +237,10 @@ def common_filters(marker=None, limit=None, sort_key=None, sort_dir=None,
         filters.append('sort_key=%s' % sort_key)
     if sort_dir is not None:
         filters.append('sort_dir=%s' % sort_dir)
+    if project is not None:
+        filters.append('project=%s' % project)
+    if public is not None:
+        filters.append('public=True')
     if fields is not None:
         filters.append('fields=%s' % ','.join(fields))
     if detail:
@@ -266,20 +271,30 @@ def make_configdrive(path):
     with tempfile.NamedTemporaryFile() as tmpfile:
         with tempfile.NamedTemporaryFile() as tmpzipfile:
             publisher = 'ironicclient-configdrive 0.1'
-            try:
-                p = subprocess.Popen(['genisoimage', '-o', tmpfile.name,
-                                      '-ldots', '-allow-lowercase',
-                                      '-allow-multidot', '-l',
-                                      '-publisher', publisher,
-                                      '-quiet', '-J',
-                                      '-r', '-V', 'config-2',
-                                      path],
-                                     stdout=subprocess.PIPE,
-                                     stderr=subprocess.PIPE)
-            except OSError as e:
+            # NOTE(toabctl): Luckily, genisoimage, mkisofs and xorrisofs
+            # understand the same parameters which are currently used.
+            cmds = ['genisoimage', 'mkisofs', 'xorrisofs']
+            for c in cmds:
+                try:
+                    p = subprocess.Popen([c, '-o', tmpfile.name,
+                                          '-ldots', '-allow-lowercase',
+                                          '-allow-multidot', '-l',
+                                          '-publisher', publisher,
+                                          '-quiet', '-J',
+                                          '-r', '-V', 'config-2',
+                                          path],
+                                         stdout=subprocess.PIPE,
+                                         stderr=subprocess.PIPE)
+                except OSError as e:
+                    error = e
+                else:
+                    error = None
+                    break
+            if error:
                 raise exc.CommandError(
                     _('Error generating the config drive. Make sure the '
-                      '"genisoimage" tool is installed. Error: %s') % e)
+                      '"genisoimage", "mkisofs", or "xorriso" tool is '
+                      'installed. Error: %s') % error)
 
             stdout, stderr = p.communicate()
             if p.returncode != 0:
@@ -366,7 +381,7 @@ def get_from_stdin(info_desc):
 def handle_json_or_file_arg(json_arg):
     """Attempts to read JSON argument from file or string.
 
-    :param json_arg: May be a file name containing the JSON, or
+    :param json_arg: May be a file name containing the YAML or JSON, or
         a JSON string.
     :returns: A list or dictionary parsed from JSON.
     :raises: InvalidAttribute if the argument cannot be parsed.
@@ -375,16 +390,16 @@ def handle_json_or_file_arg(json_arg):
     if os.path.isfile(json_arg):
         try:
             with open(json_arg, 'r') as f:
-                json_arg = f.read().strip()
+                return yaml.safe_load(f)
         except Exception as e:
-            err = _("Cannot get JSON from file '%(file)s'. "
+            err = _("Cannot get JSON/YAML from file '%(file)s'. "
                     "Error: %(err)s") % {'err': e, 'file': json_arg}
             raise exc.InvalidAttribute(err)
     try:
         json_arg = json.loads(json_arg)
     except ValueError as e:
-        err = (_("For JSON: '%(string)s', error: '%(err)s'") %
-               {'err': e, 'string': json_arg})
+        err = (_("Value '%(string)s' is not a file and cannot be parsed "
+                 "as JSON: '%(err)s'") % {'err': e, 'string': json_arg})
         raise exc.InvalidAttribute(err)
 
     return json_arg
@@ -407,6 +422,8 @@ def poll(timeout, poll_interval, poll_delay_function, timeout_message):
         poll_delay_function(poll_interval)
         count += 1
 
+    if callable(timeout_message):
+        timeout_message = timeout_message()
     raise exc.StateTransitionTimeout(timeout_message)
 
 
@@ -424,3 +441,24 @@ def handle_json_arg(json_arg, info_desc):
     if json_arg:
         json_arg = handle_json_or_file_arg(json_arg)
     return json_arg
+
+
+def get_json_data(data):
+    """Check if the binary data is JSON and parse it if so.
+
+    Only supports dictionaries.
+    """
+    # We don't want to simply loads() a potentially large binary. Doing so,
+    # in my testing, is orders of magnitude (!!) slower than this process.
+    for idx in range(len(data)):
+        char = data[idx:idx + 1]
+        if char.isspace():
+            continue
+        if char != b'{' and char != 'b[':
+            return None  # not JSON, at least not JSON we care about
+        break  # maybe JSON
+
+    try:
+        return json.loads(data)
+    except ValueError:
+        return None
