@@ -56,7 +56,7 @@ class CreateBaremetalPort(command.ShowOne):
             metavar="<key=value>",
             action='append',
             help=_("Record arbitrary key/value metadata. "
-                   "Can be specified multiple times.")
+                   "Argument can be specified multiple times.")
         )
         parser.add_argument(
             '--local-link-connection',
@@ -64,8 +64,10 @@ class CreateBaremetalPort(command.ShowOne):
             action='append',
             help=_("Key/value metadata describing Local link connection "
                    "information. Valid keys are 'switch_info', 'switch_id', "
-                   "and 'port_id'. The keys 'switch_id' and 'port_id' are "
-                   "required. Can be specified multiple times.")
+                   "'port_id' and 'hostname'. The keys 'switch_id' and "
+                   "'port_id' are required. In case of a Smart NIC port, "
+                   "the required keys are 'port_id' and 'hostname'. "
+                   "Argument can be specified multiple times.")
         )
         parser.add_argument(
             '-l',
@@ -98,6 +100,18 @@ class CreateBaremetalPort(command.ShowOne):
             help=_("Name of the physical network to which this port is "
                    "connected."))
 
+        parser.add_argument(
+            '--is-smartnic',
+            dest='is_smartnic',
+            action='store_true',
+            help=_("Indicates whether this Port is a Smart NIC port"))
+
+        parser.add_argument(
+            '--name',
+            dest='name',
+            metavar='<port name>',
+            help=_("Name of the port."))
+
         return parser
 
     def take_action(self, parsed_args):
@@ -118,11 +132,13 @@ class CreateBaremetalPort(command.ShowOne):
 
         field_list = ['address', 'uuid', 'extra', 'node_uuid', 'pxe_enabled',
                       'local_link_connection', 'portgroup_uuid',
-                      'physical_network']
+                      'physical_network', 'name']
         fields = dict((k, v) for (k, v) in vars(parsed_args).items()
                       if k in field_list and v is not None)
         fields = utils.args_array_to_dict(fields, 'extra')
         fields = utils.args_array_to_dict(fields, 'local_link_connection')
+        if parsed_args.is_smartnic:
+            fields['is_smartnic'] = parsed_args.is_smartnic
         port = baremetal_client.port.create(**fields)
 
         data = dict([(f, getattr(port, f, '')) for f in
@@ -215,6 +231,18 @@ class UnsetBaremetalPort(command.Command):
             dest='physical_network',
             help=_("Unset the physical network on this baremetal port."))
 
+        parser.add_argument(
+            '--is-smartnic',
+            dest='is_smartnic',
+            action='store_true',
+            help=_("Set Port as not Smart NIC port"))
+
+        parser.add_argument(
+            '--name',
+            dest='name',
+            action='store_true',
+            help=_("Unset the name for this port"))
+
         return parser
 
     def take_action(self, parsed_args):
@@ -232,6 +260,12 @@ class UnsetBaremetalPort(command.Command):
         if parsed_args.physical_network:
             properties.extend(utils.args_array_to_patch('remove',
                               ['physical_network']))
+        if parsed_args.is_smartnic:
+            properties.extend(utils.args_array_to_patch(
+                'add', ["is_smartnic=False"]))
+        if parsed_args.name:
+            properties.extend(utils.args_array_to_patch('remove',
+                              ['name']))
 
         if properties:
             baremetal_client.port.update(parsed_args.port, properties)
@@ -282,8 +316,10 @@ class SetBaremetalPort(command.Command):
             action='append',
             help=_("Key/value metadata describing local link connection "
                    "information. Valid keys are 'switch_info', 'switch_id', "
-                   "and 'port_id'. The keys 'switch_id' and 'port_id' are "
-                   "required. Can be specified multiple times.")
+                   "'port_id' and 'hostname'. The keys 'switch_id' and "
+                   "'port_id' are required. In case of a Smart NIC port, "
+                   "the required keys are 'port_id' and 'hostname'. "
+                   "Argument can be specified multiple times.")
         )
         pxe_enabled_group = parser.add_mutually_exclusive_group(required=False)
         pxe_enabled_group.add_argument(
@@ -309,6 +345,18 @@ class SetBaremetalPort(command.Command):
             help=_("Set the name of the physical network to which this port "
                    "is connected."))
 
+        parser.add_argument(
+            '--is-smartnic',
+            dest='is_smartnic',
+            action='store_true',
+            help=_("Set port to be Smart NIC port"))
+
+        parser.add_argument(
+            '--name',
+            metavar='<name>',
+            dest='name',
+            help=_("Set name for this port"))
+
         return parser
 
     def take_action(self, parsed_args):
@@ -342,6 +390,12 @@ class SetBaremetalPort(command.Command):
                                 parsed_args.physical_network]
             properties.extend(utils.args_array_to_patch('add',
                                                         physical_network))
+        if parsed_args.is_smartnic:
+            is_smartnic = ["is_smartnic=%s" % parsed_args.is_smartnic]
+            properties.extend(utils.args_array_to_patch('add', is_smartnic))
+        if parsed_args.name:
+            port_name = ["name=%s" % parsed_args.name]
+            properties.extend(utils.args_array_to_patch('add', port_name))
 
         if properties:
             baremetal_client.port.update(parsed_args.port, properties)
@@ -413,7 +467,7 @@ class ListBaremetalPort(command.Lister):
             type=int,
             help=_('Maximum number of ports to return per request, '
                    '0 for no limit. Default is the maximum number used '
-                   'by the Ironic API Service.')
+                   'by the Baremetal API Service.')
         )
         parser.add_argument(
             '--marker',
