@@ -47,6 +47,7 @@ class Resource(object):
         'conductor': 'Conductor',
         'conductor_group': 'Conductor Group',
         'console_enabled': 'Console Enabled',
+        'count': 'Count',
         'created_at': 'Created At',
         'default_bios_interface': 'Default BIOS Interface',
         'default_boot_interface': 'Default Boot Interface',
@@ -157,8 +158,8 @@ class Resource(object):
         'parent_node': 'Parent Node',
         'children': 'Child Nodes',
         'firmware_interface': 'Firmware Interface',
-        'port_name': 'Port Name',
-        'public': 'Public'
+        'public': 'Public',
+        'disable_power_off': 'Disable Power Off'
     }
 
     def __init__(self, field_ids, sort_excluded=None, override_labels=None):
@@ -256,6 +257,7 @@ NODE_DETAILED_RESOURCE = Resource(
      'deploy_interface',
      'deploy_step',
      'description',
+     'disable_power_off',
      'driver',
      'driver_info',
      'driver_internal_info',
@@ -347,7 +349,7 @@ PORT_DETAILED_RESOURCE = Resource(
      'updated_at',
      'internal_info',
      'is_smartnic',
-     'port_name',
+     'name',
      ],
     sort_excluded=[
         'extra',
@@ -643,3 +645,8 @@ NODE_HISTORY_DETAILED_RESOURCE = Resource(
      'conductor',
      'user']
 )
+
+SHARD_RESOURCE = Resource(
+    ['name',
+     'count']
+)
