@@ -16,16 +16,12 @@
 """Provides methods needed by installation script for OpenStack development
 virtual environments.
 
-Since this script is used to bootstrap a virtualenv from the system's Python
-environment, it should be kept strictly compatible with Python 3.6.
-
 Synced in from openstack-common
 """
 
 import optparse
 import os
 import subprocess
-import sys
 
 
 class InstallVenv(object):
@@ -44,10 +40,6 @@ class InstallVenv(object):
         print(message % args, file=sys.stderr)
         sys.exit(1)
 
-    def check_python_version(self):
-        if sys.version_info < (3, 6):
-            self.die("Need Python Version >= 3.6")
-
     def run_command_with_code(self, cmd, redirect_output=True,
                               check_exit_code=True):
         """Runs a command in an out-of-process shell.
